@@ -36,11 +36,6 @@
 
 #include "grl-podcasts.h"
 
-#define GRL_PODCASTS_GET_PRIVATE(object)                        \
-  (G_TYPE_INSTANCE_GET_PRIVATE((object),                        \
-                               GRL_PODCASTS_SOURCE_TYPE,        \
-                               GrlPodcastsPrivate))
-
 #define GRL_ROOT_TITLE "Podcasts"
 
 /* --------- Logging  -------- */
@@ -330,6 +325,8 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
 
 /* ================== Podcasts GObject ================ */
 
+G_DEFINE_TYPE_WITH_PRIVATE (GrlPodcastsSource, grl_podcasts_source, GRL_TYPE_SOURCE)
+
 static GrlPodcastsSource *
 grl_podcasts_source_new (void)
 {
@@ -363,8 +360,6 @@ grl_podcasts_source_class_init (GrlPodcastsSourceClass * klass)
   source_class->remove = grl_podcasts_source_remove;
   source_class->notify_change_start = grl_podcasts_source_notify_change_start;
   source_class->notify_change_stop = grl_podcasts_source_notify_change_stop;
-
-  g_type_class_add_private (klass, sizeof (GrlPodcastsPrivate));
 }
 
 static void
@@ -375,7 +370,7 @@ grl_podcasts_source_init (GrlPodcastsSource *source)
   gchar *db_path;
   gchar *sql_error = NULL;
 
-  source->priv = GRL_PODCASTS_GET_PRIVATE (source);
+  source->priv = grl_podcasts_source_get_instance_private (source);
 
   path = g_strconcat (g_get_user_data_dir (),
                       G_DIR_SEPARATOR_S, "grilo-plugins",
@@ -423,8 +418,6 @@ grl_podcasts_source_init (GrlPodcastsSource *source)
   GRL_DEBUG ("  OK");
 }
 
-G_DEFINE_TYPE (GrlPodcastsSource, grl_podcasts_source, GRL_TYPE_SOURCE);
-
 static void
 grl_podcasts_source_finalize (GObject *object)
 {
@@ -638,10 +631,8 @@ build_media (GrlMedia *content,
 
     grl_media_set_id (media, url);
     if (date) {
-      time_t t;
       GDateTime *date_time;
-      t = g_mime_utils_header_decode_date (date, NULL);
-      date_time = g_date_time_new_from_unix_utc (t);
+      date_time = g_mime_utils_header_decode_date (date);
       grl_media_set_publication_date (media, date_time);
       g_date_time_unref (date_time);
     }
@@ -778,7 +769,7 @@ produce_podcast_contents_from_db (OperationSpec *os)
   }
 
   if (r != SQLITE_DONE) {
-    GRL_WARNING ("Failed to retrive podcast streams: %s", sqlite3_errmsg (db));
+    GRL_WARNING ("Failed to retrieve podcast streams: %s", sqlite3_errmsg (db));
     error = g_error_new (GRL_CORE_ERROR,
                          os->error_code,
                          _("Failed to get podcast streams: %s"),
@@ -1277,8 +1268,10 @@ parse_feed (OperationSpec *os, const gchar *str, GError **error)
   /* Check podcast pubDate (if available), if it has not been updated
      recently then we can use the cache and avoid parsing the feed */
   if (podcast_data->published != NULL) {
-    time_t pub_time =
-      g_mime_utils_header_decode_date (podcast_data->published, NULL);
+    GDateTime *date_time =
+      g_mime_utils_header_decode_date (podcast_data->published);
+    gint64 pub_time = g_date_time_to_unix (date_time);
+    g_date_time_unref (date_time);
     if (pub_time == 0) {
       GRL_DEBUG ("Invalid podcast pubDate: '%s'", podcast_data->published);
       /* We will parse the feed again just in case */
