@@ -53,6 +53,7 @@ typedef void (*tracker_grl_sparql_setter_cb_t) (TrackerSparqlCursor *cursor,
 typedef struct {
   GrlKeyID     grl_key;
   const gchar *sparql_key_name;
+  const gchar *sparql_key_name_canon;
   const gchar *sparql_key_attr;
   const gchar *sparql_key_attr_call;
   const gchar *sparql_key_flavor;
@@ -70,7 +71,8 @@ void grl_tracker_setup_key_mappings (void);
 
 tracker_grl_sparql_t *grl_tracker_get_mapping_from_sparql (const gchar *key);
 
-GrlMedia *grl_tracker_build_grilo_media (const gchar *rdf_type);
+GrlMedia *grl_tracker_build_grilo_media (const gchar   *rdf_type,
+                                         GrlTypeFilter  type_filter);
 
 gchar *grl_tracker_source_get_device_constraint (GrlTrackerSourcePriv *priv);
 
